Welcome to Mistral's documentation!
===================================

Mistral is the OpenStack workflow service. This project aims to provide
a mechanism to define tasks and workflows without writing code, manage
and execute them in the cloud environment.

Overview
--------

.. toctree::
    :maxdepth: 1

    overview
    quickstart
    architecture
    terminology/index
    main_features
    cookbooks

User guide
----------

**Installation**

.. toctree::
   :maxdepth: 1

   guides/installation_guide
   guides/configuration_guide
   guides/dashboard_guide
   guides/upgrade_guide
   guides/mistralclient_guide

**API**

.. toctree::
   :maxdepth: 2

   developer/webapi/index

**DSL**

.. toctree::
   :maxdepth: 2

   dsl/index

**CLI**

.. toctree::
   :maxdepth: 1

   guides/cli_guide

Developer guide
---------------

.. toctree::
   :maxdepth: 2

   developer/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

